@@ -2,14 +2,6 @@
 mod arm;
 #[cfg(target_arch = "arm")]
 pub use arm::*;
-#[cfg(target_arch = "riscv32")]
-mod riscv32;
-#[cfg(target_arch = "riscv32")]
-pub use riscv32::*;
-#[cfg(target_arch = "riscv64")]
-mod riscv64;
-#[cfg(target_arch = "riscv64")]
-pub use riscv64::*;
 #[cfg(target_arch = "mips")]
 mod mips;
 #[cfg(target_arch = "mips")]
@@ -18,6 +10,10 @@ pub use mips::*;
 mod mips64;
 #[cfg(target_arch = "mips64")]
 pub use mips64::*;
+#[cfg(target_arch = "avr")]
+mod avr;
+#[cfg(target_arch = "avr")]
+pub use avr::*;
 #[cfg(target_arch = "powerpc")]
 mod powerpc;
 #[cfg(target_arch = "powerpc")]
@@ -30,14 +26,6 @@ pub use powerpc64::*;
 mod s390x;
 #[cfg(target_arch = "s390x")]
 pub use s390x::*;
-#[cfg(target_arch = "aarch64")]
-mod aarch64;
-#[cfg(target_arch = "aarch64")]
-pub use aarch64::*;
-#[cfg(target_arch = "hexagon")]
-mod hexagon;
-#[cfg(target_arch = "hexagon")]
-pub use hexagon::*;
 #[cfg(target_arch = "x86")]
 mod x86;
 #[cfg(target_arch = "x86")]
